package
module
Version:
v0.0.0-...-aeb6479
Opens a new window with list of versions in this module.
Published: Jul 4, 2019
License: LGPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
event
A simple event manager
License
This project is licensed under the LGPL-3.0 License - see the LICENSE.md file for details
Documentation
¶
type Callback func(...interface{})
func (e *Event) Fire(name int, l ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.